Module fastq

Module fastq 

Efficient FASTQ reading and writing

Structs

ErrorPosition
OwnedRecord
A FASTQ record that ownes its data (requires allocations)
Position
Holds line number and byte offset of a FASTQ record
Reader
FASTQ parser.
RecordSet
Set of FASTQ records that owns it’s buffer and knows the positions of each record.
RecordSetIter
Iterator over record sets
RecordsIntoIter
Iterator of OwnedRecord that owns the underlying reader
RecordsIter
Borrowed iterator of OwnedRecord
RefRecord
A FASTQ record that borrows data from a buffer

Enums

Error
FASTQ parsing error

Traits

Record
FASTQ record trait implemented by both RefRecord and OwnedRecord

Functions

write_parts
Helper function for writing data (not necessarily stored in a Record instance) to the FASTQ format. The ID and description parts of the header are supplied separately instead of a whole header line
write_to
Helper function for writing data (not necessarily stored in a Record instance) to the FASTQ format