seq_io_parallel::processor

Trait ParallelProcessor

pub trait ParallelProcessor: Send + Clone {
    // Required method
    fn process_record<'a, Rf: MinimalRefRecord<'a>>(
        &mut self,
        record: Rf,
    ) -> Result<()>;

    // Provided methods
    fn on_batch_complete(&mut self) -> Result<()> { ... }
    fn on_thread_complete(&mut self) -> Result<()> { ... }
    fn set_thread_id(&mut self, thread_id: usize) { ... }
    fn get_thread_id(&self) -> usize { ... }
}
Trait implemented for a type that processes records in parallel

Required Methods

fn process_record<'a, Rf: MinimalRefRecord<'a>>( &mut self, record: Rf, ) -> Result<()>

Called on an individual record

Provided Methods

fn on_batch_complete(&mut self) -> Result<()>

Called when a batch of records is complete

fn on_thread_complete(&mut self) -> Result<()>

Called when the processing for a thread is complete

fn set_thread_id(&mut self, thread_id: usize)

Sets the thread id for the processor

fn get_thread_id(&self) -> usize

Gets the thread id for the processor

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors