Efficient FASTQ reading and writing
Structs
- Error
Position - Owned
Record - A FASTQ record that ownes its data (requires allocations)
- Position
- Holds line number and byte offset of a FASTQ record
- Reader
- FASTQ parser.
- Record
Set - Set of FASTQ records that owns it’s buffer and knows the positions of each record.
- Record
SetIter - Iterator over record sets
- Records
Into Iter - Iterator of
OwnedRecordthat owns the underlying reader - Records
Iter - Borrowed iterator of
OwnedRecord - RefRecord
- A FASTQ record that borrows data from a buffer
Enums
- Error
- FASTQ parsing error
Traits
- Record
- FASTQ record trait implemented by both
RefRecordandOwnedRecord
Functions
- write_
parts - Helper function for writing data (not necessarily stored in a
Recordinstance) to the FASTQ format. The ID and description parts of the header are supplied separately instead of a whole header line - write_
to - Helper function for writing data (not necessarily stored in a
Recordinstance) to the FASTQ format